==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/get_properties.py <==
import re

def snake_case(s):
    s = str(s)
    _underscorer1 = re.compile(r'(.)([A-Z][a-z]+)')
    _underscorer2 = re.compile('([a-z0-9])([A-Z])')
    subbed = _underscorer1.sub(r'\1_\2', s)
    return _underscorer2.sub(r'\1_\2', subbed).lower()

def substitute_mbean(s):
    s = str(s)
    _mbean = re.compile(r'(.)(MBean)(.)')
    return _mbean.sub(r'\1Mbean\3', s)

def descriptor_for(key):
    return getMBI().getAttribute(key).descriptor

def description_for(key):
    try:
        descriptor  = descriptor_for(key)
        description = descriptor.getFieldValue('com.bea.description')
    except:
        description = ''
    description = re.sub('<\/?.>', '', description)
    return description

def default_value_for(key):
    try:
        descriptor = descriptor_for(key)
        value = descriptor.getFieldValue('defaultValue')
        if value:
            return value
        else:
            return 'a_value'
    except:
        return 'a_value'

def valid_property(property):
    if property in ['Id', 'Name','Type','DynamicallyCreated','LastModificationTime', 'Parent', 'DescriptorFileName', 'CustomClusterConfigurationFileName']:
        return False
    if re.search(".*Encrypted$", property) != None:
        return False
    return True

def properties(path = None, wls_type = '', prefix = '', map_prefix = ''):
    edit()
    if path == None:
        path = pwd()
    cd(path)
    wls_properties = ls(path, returnMap='true', returnType='a')

    for element in wls_properties:
        if valid_property(element):
            attribute_name = snake_case(substitute_mbean(element))
            # If names already starts with prefix don't add it
            if attribute_name[:len(prefix)] != prefix:
                attribute_name = prefix + attribute_name
            print 'creating property file ' + attribute_name
            full_path      = path + '/' + element
            attribute_help = description_for(element)
            default_value  = default_value_for(element)
            file_name      = attribute_name + '.rb'
            property_file  = open(file_name, 'w')
            property_type  = type_for(path + '/' + element)
            if is_encrypted(full_path):
                property_file.write('  newproperty(:' + attribute_name + ', :parent => Puppet::Parameter::WlsEncryptedProperty) do\n')
                if wls_type == 'wls_domain':
                    property_file.write('extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource\n')
            else:
                property_file.write('newproperty(:' + attribute_name + ', :parent => Puppet::Parameter::WlsProperty) do\n')
                if wls_type == 'wls_domain':
                    property_file.write('  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource\n')

            if property_type in ['int', 'long']:
                property_file.write('  include EasyType::Validators::Integer\n')

            property_file.write('\n')
            property_file.write('  desc <<-EOD\n')
            property_file.write('  ' + attribute_help + '\n')
            property_file.write('\n')
            property_file.write('  An example on how to use this:\n')
            property_file.write('\n')
            property_file.write('      ' + wls_type + ' {a_' + wls_type +' :\n')
            property_file.write('         ...\n')
            if property_type == 'boolean':
                property_file.write('         ' + attribute_name + " => '1'\n")
            else:
                property_file.write('         ' + attribute_name + " => '" + str(default_value) + "'\n")
            property_file.write('         ...\n')
            property_file.write('      }\n')
            property_file.write('\n')
            property_file.write('  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.\n')
            property_file.write('\n')
            property_file.write("      wls_setting{'domain':\n")
            property_file.write('         ...\n')
            property_file.write("        extra_properties => ['" + wls_type + ':' + attribute_name + "']\n")
            property_file.write('         ...\n')
            property_file.write("      }\n")
            property_file.write('\n')
            property_file.write('  This help text generated from MBean text of the WebLogic server.\n')
            property_file.write('\n')
            property_file.write('  EOD\n')
            property_file.write('\n')
            if property_type == 'boolean':
                property_file.write("  newvalues('absent', '0', '1')\n")
                property_file.write('\n')
            property_file.write("  maps_to('" + map_prefix + element + "')\n")
            property_file.write('end\n')
            property_file.flush()
            property_file.close()

==> enterprisemodules-wls_config-3.1.0.tar.gz: enterprisemodules-wls_config-3.1.0/meta/get_properties.py <==
import re

def snake_case(s):
    s = str(s)
    _underscorer1 = re.compile(r'(.)([A-Z][a-z]+)')
    _underscorer2 = re.compile('([a-z0-9])([A-Z])')
    subbed = _underscorer1.sub(r'\1_\2', s)
    return _underscorer2.sub(r'\1_\2', subbed).lower()

def substitute_mbean(s):
    s = str(s)
    _mbean = re.compile(r'(.)(MBean)(.)')
    return _mbean.sub(r'\1Mbean\3', s)

def descriptor_for(key):
    return getMBI().getAttribute(key).descriptor

def description_for(key):
    try:
        descriptor  = descriptor_for(key)
        description = descriptor.getFieldValue('com.bea.description')
    except:
        description = ''
    description = re.sub('<\/?.>', '', description)
    return description

def default_value_for(key):
    try:
        descriptor = descriptor_for(key)
        value = descriptor.getFieldValue('defaultValue')
        if value:
            return value
        else:
            return 'a_value'
    except:
        return 'a_value'

def valid_property(property):
    if property in ['Id', 'Name','Type','DynamicallyCreated','LastModificationTime', 'Parent', 'DescriptorFileName', 'CustomClusterConfigurationFileName']:
        return False
    if re.search(".*Encrypted$", property) != None:
        return False
    return True

def properties(path = None, wls_type = '', prefix = '', map_prefix = ''):
    edit()
    if path == None:
        path = pwd()
    cd(path)
    wls_properties = ls(path, returnMap='true', returnType='a')

    for element in wls_properties:
        if valid_property(element):
            attribute_name = snake_case(substitute_mbean(element))
            # If names already starts with prefix don't add it
            if attribute_name[:len(prefix)] != prefix:
                attribute_name = prefix + attribute_name
            print 'creating property file ' + attribute_name
            full_path      = path + '/' + element
            attribute_help = description_for(element)
            default_value  = default_value_for(element)
            file_name      = attribute_name + '.rb'
            property_file  = open(file_name, 'w')
            property_type  = type_for(path + '/' + element)
            if is_encrypted(full_path):
                property_file.write('  newproperty(:' + attribute_name + ', :parent => Puppet::Parameter::WlsEncryptedProperty) do\n')
                if wls_type == 'wls_domain':
                    property_file.write('extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource\n')
            else:
                property_file.write('newproperty(:' + attribute_name + ', :parent => Puppet::Parameter::WlsProperty) do\n')
                if wls_type == 'wls_domain':
                    property_file.write('  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource\n')

            if property_type in ['int', 'long']:
                property_file.write('  include EasyType::Validators::Integer\n')

            property_file.write('\n')
            property_file.write('  desc <<-EOD\n')
            property_file.write('  ' + attribute_help + '\n')
            property_file.write('\n')
            property_file.write('  An example on how to use this:\n')
            property_file.write('\n')
            property_file.write('      ' + wls_type + ' {a_' + wls_type +' :\n')
            property_file.write('         ...\n')
            if property_type == 'boolean':
                property_file.write('         ' + attribute_name + " => '1'\n")
            else:
                property_file.write('         ' + attribute_name + " => '" + str(default_value) + "'\n")
            property_file.write('         ...\n')
            property_file.write('      }\n')
            property_file.write('\n')
            property_file.write('  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.\n')
            property_file.write('\n')
            property_file.write("      wls_setting{'domain':\n")
            property_file.write('         ...\n')
            property_file.write("        extra_properties => ['" + wls_type + ':' + attribute_name + "']\n")
            property_file.write('         ...\n')
            property_file.write("      }\n")
            property_file.write('\n')
            property_file.write('  This help text generated from MBean text of the WebLogic server.\n')
            property_file.write('\n')
            property_file.write('  EOD\n')
            property_file.write('\n')
            if property_type == 'boolean':
                property_file.write("  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean\n")
                property_file.write('\n')
            property_file.write("  maps_to('" + map_prefix + element + "')\n")
            property_file.write('end\n')
            property_file.flush()
            property_file.close()
